"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("./common/util");
const jsdom_1 = require("jsdom");
const commander_1 = require("commander");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
function initProgram() {
    commander_1.program
        .description("Convert html bookmark links to .url format files.")
        .option("-i, --input <input>", "input file path", "./bookmarks.html")
        .option("-o, --output <output>", "output directory path", "./bookmarks/");
    commander_1.program.parse();
    return commander_1.program.opts();
}
async function main() {
    const options = initProgram();
    console.log("Converting html bookmark links to .url format files");
    const data = await (0, util_1.importUrlFile)(options.input);
    const aTagList = new jsdom_1.JSDOM(data).window.document.getElementsByTagName("A");
    const outputPath = path_1.default.join("./", options.output, "/");
    if (fs_1.default.existsSync(outputPath))
        throw new Error("Output directory already exists. Please delete it manually.");
    await fs_1.default.promises.mkdir(outputPath);
    for (let i = 0; i < aTagList.length; i++) {
        let title = aTagList.item(i)?.textContent ?? "";
        // replace specific characters with "_"
        ["\\", "/", ":", "*", "?", "<", ">", "|", " ", "　"].map(mark => (title = title.replaceAll(mark, "_")));
        const href = aTagList.item(i)?.getAttribute("href");
        if (!href)
            console.error(`DOM error on ${title}`);
        await (0, util_1.generateUrlFile)(outputPath, `${title}.url`, href ?? "");
    }
}
exports.default = main;
//# sourceMappingURL=index.js.map